using FitConnect.Models;

namespace FitConnect;

public interface ISendableSubmission {
    string DestinationId { get; }
    string? ServiceName { get; }
    string? LeikaKey { get; }
    string? Data { get; }
}

public class SendableSubmission : ISendableSubmission {
    public string DestinationId { get; internal set; }
    public string? ServiceName { get; internal set; }
    public string? LeikaKey { get; internal set; }
    public Attachment[]? Attachments { get; internal set; }
    public string? Data { get; internal set; }

    internal SendableSubmission(string destinationId) {
        DestinationId = destinationId;
    }
}

public class SendableEncryptedSubmission : ISendableSubmission {
    public string DestinationId { get; set; }
    public string? ServiceName { get; set; }
    public string? LeikaKey { get; set; }
    
    /// <summary>
    /// The encrypted data.
    /// </summary>
    public string? Data { get; set; }
    public string? Metadata { get; set; }
    public Dictionary<string, string>? Attachments { get; set; }

    public SendableEncryptedSubmission(string destinationId) {
        DestinationId = destinationId;
    }
}
